pub enum PingOutcome {
Show 14 variants
HostDidntRespondToPingMethods {
tcp: bool,
icmp: bool,
},
IcmpEchoPacket,
HostLocalNetworkDidntRespondArpWhoIsQuery,
ArpWhoIsQuery(MacAddress),
IcmpUnreachPacketInResponseToTcpSynPacket {
to: u16,
},
RepliedTcpSynPacketWithRstAck {
to: u16,
},
RepliedTcpSynPacketWithSynAck {
to: u16,
},
RepliedTcpSynPacketWithFinAck {
to: u16,
},
EmittedTcpSynPacket {
from: u16,
to: u16,
},
EmittedTcpAckPacket {
from: u16,
to: u16,
},
EmittedTcpPushAckPacket {
from: u16,
to: u16,
},
IcmpUnreachPacket,
EmittedUdpPacket {
from: u16,
to: u16,
},
LocalScanner,
}Expand description
Structured interpretation of the plugin_output text for
Nessus plugin 10180 (“Ping the remote host”).
Variants
HostDidntRespondToPingMethods
The host was marked dead after no response to one or more ping methods.
IcmpEchoPacket
The host replied to an ICMP echo packet.
HostLocalNetworkDidntRespondArpWhoIsQuery
The host is local-network reachable via ARP checks but did not answer ARP who-is.
ArpWhoIsQuery(MacAddress)
The host replied to an ARP who-is query with the given MAC address.
IcmpUnreachPacketInResponseToTcpSynPacket
The host replied with ICMP unreachable to a TCP SYN probe sent to to.
RepliedTcpSynPacketWithRstAck
The host replied to a TCP SYN probe with RST,ACK.
RepliedTcpSynPacketWithSynAck
The host replied to a TCP SYN probe with SYN,ACK.
RepliedTcpSynPacketWithFinAck
The host replied to a TCP SYN probe with FIN,ACK.
EmittedTcpSynPacket
The host emitted a TCP SYN packet.
EmittedTcpAckPacket
The host emitted a TCP ACK packet.
EmittedTcpPushAckPacket
The host emitted a TCP PUSH,ACK packet.
IcmpUnreachPacket
The host replied with a generic ICMP unreachable packet.
EmittedUdpPacket
The host emitted a UDP packet.
LocalScanner
The target host is the same machine as the Nessus scanner.