Module report

Module report 

Types for Nessus <Report> data, including hosts and derived findings metadata.

Modules

item
Types for Nessus <ReportItem> findings and their normalized fields.

Structs

Host
Represents a <ReportHost> element, containing all information gathered for a single host.
HostProperties
Represents the <HostProperties> element, a collection of key-value tags containing detailed metadata about a scanned host.
Report
Represents the <Report> element, which contains the main body of the scan results.