Module item

Module item 

Types for Nessus <ReportItem> findings and their normalized fields.

Structs

Item
Represents a <ReportItem> element, which is a single finding or piece of information reported by a Nessus plugin for a specific host and port.

Enums

Level
Normalized severity/risk level.
PluginType
Execution context/type of a Nessus plugin finding.
Protocol
Network transport protocol attached to a report item.